"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.transformFile = exports.resetLabel = exports.getRandom = exports.getInitKeyValue = exports.getByteLen = exports.filterObjList = exports.dateNameReplace = exports.dateChange = exports.changeDateFormat = void 0;

var _dayjs = _interopRequireDefault(require("dayjs"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

var getInitKeyValue = function getInitKeyValue(_ref) {
  var form = _ref.form,
      key = _ref.key,
      data = _ref.data;
  var filter = data.filter(function (item) {
    return (item === null || item === void 0 ? void 0 : item.initKey) === key;
  });
  var obj = {};
  filter.forEach(function (item) {
    obj[item.fieldProps] = form.getFieldValue(item.fieldProps);
  });
  return obj;
};
/**
 * 将带中文的日期值 修改成底层组件能读懂的内容
 */


exports.getInitKeyValue = getInitKeyValue;

var dateNameReplace = function dateNameReplace(_ref2) {
  var value = _ref2.value,
      replaceName = _ref2.replaceName;
  var val = value;
  var reg = new RegExp("[\\u4E00-\\u9FFF]+", 'g');

  if (replaceName && val && typeof val === 'string' && reg.test(val)) {
    Object.entries(replaceName).forEach(function (_ref3) {
      var _ref4 = _slicedToArray(_ref3, 2),
          key = _ref4[0],
          name = _ref4[1];

      val = val.replace(key, name);
    });

    if (val.endsWith('-')) {
      val = val.slice(0, val.length - 1);
    }
  }

  return val;
};
/**
 * 时间展示类型改变事件
 * @param val
 */


exports.dateNameReplace = dateNameReplace;

var changeDateFormat = function changeDateFormat(_ref5) {
  var value = _ref5.value,
      modeType = _ref5.modeType,
      format = _ref5.format,
      replaceName = _ref5.replaceName;
  if (!value) return '';
  var dateFormat = '';
  var val = dateNameReplace({
    value: value,
    replaceName: replaceName
  });

  switch (modeType) {
    case 'datetime':
      dateFormat = (0, _dayjs.default)(val).format('YYYY-MM-DD HH:mm');
      break;

    case 'month':
      dateFormat = (0, _dayjs.default)(val).format('YYYY-MM');
      break;

    case 'time':
      dateFormat = (0, _dayjs.default)(val).format('HH:mm');
      break;

    case 'year':
      dateFormat = (0, _dayjs.default)(val).format('YYYY');
      break;

    default:
      dateFormat = (0, _dayjs.default)(val).format('YYYY-MM-DD');
      break;
  }

  if (format && typeof format === 'string') {
    dateFormat = (0, _dayjs.default)(val).format(format);
  }

  if (format && val && typeof val !== 'string' && typeof format === 'function') {
    dateFormat = format(val);
  }

  return dateFormat;
};

exports.changeDateFormat = changeDateFormat;

var dateChange = function dateChange(date) {
  if (!date) return date;
  var stringDate = (0, _dayjs.default)(date).format('YYYY-MM-DD-HH-mm-ss');
  var dateList = stringDate.split('-');
  var numberDateList = dateList.map(function (item) {
    return parseInt(item, 10);
  });
  return new Date(numberDateList[0], numberDateList[1] - 1, numberDateList[2], numberDateList[3], numberDateList[4], numberDateList[5]);
};

exports.dateChange = dateChange;

var getByteLen = function getByteLen(val) {
  var len = 0;
  "".concat(val).split('').forEach(function (item) {
    // eslint-disable-next-line no-control-regex
    if (item.match(/[^\x00-\xff]/gi) != null) {
      len += 2;
    } else {
      len += 1;
    }
  });
  return len;
};

exports.getByteLen = getByteLen;

var resetLabel = function resetLabel() {
  var list = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
  var placeholderList = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
  if (list.length === placeholderList.length) return list;
  list.push(placeholderList[list.length]);
  return list;
};

exports.resetLabel = resetLabel;

var filterObjList = function filterObjList() {
  var label = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
  var data = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
  var value = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : '';

  if (data && data.length) {
    var filList = [];
    filList = data.filter(function (it) {
      return it[label] === value;
    });
    return filList;
  }

  return [];
};
/**
 * 设置随机值
 */


exports.filterObjList = filterObjList;

var getRandom = function getRandom() {
  var val = "".concat(Math.random().toString(36).slice(2, 6));
  return val;
};
/**
 * 压缩图片
 */


exports.getRandom = getRandom;

var transformFile = function transformFile(file) {
  var pictureQuality = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0.5;

  /**
   * 针对图片进行压缩,如果图片大小超过压缩阈值,则执行压缩,否则不压缩
   */
  //判断是否是图片类型
  // const pictureQuality = 0.5;
  if (typeof FileReader === 'undefined') {
    return file;
  } else {
    try {
      return new Promise(function (resolve) {
        //声明FileReader文件读取对象
        var reader = new FileReader();
        reader.readAsDataURL(file);

        reader.onload = function () {
          // 生成canvas画布
          var canvas = document.createElement('canvas'); // 生成img

          var img = document.createElement('img');
          img.src = reader.result;

          img.onload = function () {
            var ctx = canvas.getContext('2d'); //原始图片宽度、高度

            var originImageWidth = img.width,
                originImageHeight = img.height; //默认最大尺度的尺寸限制在（1920 * 1080）

            var maxWidth = 1920,
                maxHeight = 1080,
                ratio = maxWidth / maxHeight; //目标尺寸

            var targetWidth = originImageWidth,
                targetHeight = originImageHeight; //当图片的宽度或者高度大于指定的最大宽度或者最大高度时,进行缩放图片

            if (originImageWidth > maxWidth || originImageHeight > maxHeight) {
              //超过最大宽高比例
              if (originImageWidth / originImageHeight > ratio) {
                //宽度取最大宽度值maxWidth,缩放高度
                targetWidth = maxWidth;
                targetHeight = Math.round(maxWidth * (originImageHeight / originImageWidth));
              } else {
                //高度取最大高度值maxHeight,缩放宽度
                targetHeight = maxHeight;
                targetWidth = Math.round(maxHeight * (originImageWidth / originImageHeight));
              }
            } // canvas对图片进行缩放


            canvas.width = targetWidth;
            canvas.height = targetHeight; // 清除画布

            ctx.clearRect(0, 0, targetWidth, targetHeight); // 绘制图片

            ctx.drawImage(img, 0, 0, targetWidth, targetHeight); // quality值越小,图像越模糊,默认图片质量为0.92

            var imageDataURL = canvas.toDataURL(file.type || 'image/jpeg', pictureQuality); // 去掉URL的头,并转换为byte

            var imageBytes = window.atob(imageDataURL.split(',')[1]); // 处理异常,将ascii码小于0的转换为大于0

            var arrayBuffer = new ArrayBuffer(imageBytes.length);
            var uint8Array = new Uint8Array(arrayBuffer);

            for (var i = 0; i < imageBytes.length; i++) {
              uint8Array[i] = imageBytes.charCodeAt(i);
            }

            var mimeType = imageDataURL.split(',')[0].match(/:(.*?);/)[1];
            var newFile = new File([uint8Array], file.name, {
              type: mimeType || 'image/jpeg'
            }); // console.log('after compress, the file size is : ', (newFile.size / 1024 / 1024) + "M");

            resolve(newFile);
          };
        };

        reader.onerror = function () {
          return file;
        };
      }).then(function (res) {
        return res;
      }).catch(function () {
        return file;
      });
    } catch (e) {
      //压缩出错,直接返回原file对象
      return file;
    }
  }
};

exports.transformFile = transformFile;